summaryrefslogtreecommitdiffstats
path: root/lib/private/files/storage
diff options
context:
space:
mode:
authorBjoern Schiessle <schiessle@owncloud.com>2015-09-29 13:17:39 +0200
committerBjoern Schiessle <schiessle@owncloud.com>2015-10-01 10:10:19 +0200
commite7232a848bd0c0846ea020f7b07f2cfe1298b1fb (patch)
treefafa258483b99fa6b7d0e62db2e40650b8cc3bc4 /lib/private/files/storage
parent50874de1cae27907ec17f481dd5e1117cc3bdc78 (diff)
downloadnextcloud-server-e7232a848bd0c0846ea020f7b07f2cfe1298b1fb.tar.gz
nextcloud-server-e7232a848bd0c0846ea020f7b07f2cfe1298b1fb.zip
versions should always use the keys of the original file, no need to create new one
Diffstat (limited to 'lib/private/files/storage')
-rw-r--r--lib/private/files/storage/wrapper/encryption.php26
1 files changed, 24 insertions, 2 deletions
diff --git a/lib/private/files/storage/wrapper/encryption.php b/lib/private/files/storage/wrapper/encryption.php
index 805a2bc1ad0..c80e935b982 100644
--- a/lib/private/files/storage/wrapper/encryption.php
+++ b/lib/private/files/storage/wrapper/encryption.php
@@ -232,7 +232,11 @@ class Encryption extends Wrapper {
$result = $this->storage->rename($path1, $path2);
- if ($result && $this->encryptionManager->isEnabled()) {
+ if ($result &&
+ // versions always use the keys from the original file, so we can skip
+ // this step for versions
+ $this->isVersion($path2) === false &&
+ $this->encryptionManager->isEnabled()) {
$source = $this->getFullPath($path1);
if (!$this->util->isExcluded($source)) {
$target = $this->getFullPath($path2);
@@ -449,7 +453,7 @@ class Encryption extends Wrapper {
public function copyFromStorage(Storage $sourceStorage, $sourceInternalPath, $targetInternalPath, $preserveMtime = false) {
// TODO clean this up once the underlying moveFromStorage in OC\Files\Storage\Wrapper\Common is fixed:
// - call $this->storage->moveFromStorage() instead of $this->copyBetweenStorage
// - copy the file cache update from $this->copyBetweenStorage to this method
// - copy the copyKeys() call from $this->copyBetweenStorage to this method
// - remove $this->copyBetweenStorage
@@ -469,6 +473,13 @@ class Encryption extends Wrapper {
*/
private function copyBetweenStorage(Storage $sourceStorage, $sourceInternalPath, $targetInternalPath, $preserveMtime, $isRename) {
+ // for versions we have nothing to do, because versions should always use the
+ // key from the original file. Just create a 1:1 copy and done
+ if ($this->isVersion($targetInternalPath) ||
+ $this->isVersion($sourceInternalPath)) {
+ return $this->storage->copyFromStorage($sourceStorage, $sourceInternalPath, $targetInternalPath);
+ }
+
// first copy the keys that we reuse the existing file key on the target location
// and don't create a new one which would break versions for example.
$mount = $this->mountManager->findByStorageId($sourceStorage->getId());
@@ -741,4 +752,15 @@ class Encryption extends Wrapper {
return false;
}
+ /**
+ * check if path points to a files version
+ *
+ * @param $path
+ * @return bool
+ */
+ protected function isVersion($path) {
+ $normalized = Filesystem::normalizePath($path);
+ return substr($normalized, 0, strlen('/files_versions/')) === '/files_versions/';
+ }
+
}
@@ -449,7 +453,7 @@ class Encryption extends Wrapper {
public function copyFromStorage(Storage $sourceStorage, $sourceInternalPath, $targetInternalPath, $preserveMtime = false) {
// TODO clean this up once the underlying moveFromStorage in OC\Files\Storage\Wrapper\Common is fixed:
- // - call $this->storage->moveFromStorage() instead of $this->copyBetweenStorage
+ // - call $this->storage->copyFromStorage() instead of $this->copyBetweenStorage
// - copy the file cache update from $this->copyBetweenStorage to this method
// - copy the copyKeys() call from $this->copyBetweenStorage to this method